@@ -3,6 +3,7 @@
 #' Normalizes a matrix of variables based on nonlinear scaling normalization method.
 #' @param A Matrix of variables.
 #' @param chart.type  Defaults to NULL.  'l' for line, 'b' for boxplot
+#' @param location Location of legend in plot.  Defaults to 'topright'
 #' @author Fred Viole, OVVO Financial Systems
 #' @references Viole, F. and Nawrocki, D. (2013) "Nonlinear Nonparametric Statistics: Using Partial Moments"
 #' \url{http://amzn.com/1490523995}
@@ -13,7 +14,7 @@
 #' \dontrun{VN.norm(A, chart.type='l')}
 #' @export
 
-VN.norm <- function(A,chart.type=NULL) {
+VN.norm <- function(A,chart.type=NULL,location = NULL) {
   m  <- colMeans(A)
   RG <- m %o% (1/m)
   scales <- colMeans(RG * abs(cor(A)))
@@ -41,10 +42,10 @@ if(!is.null(chart.type)){
   par(mfrow=c(2,1))
 
   matplot(A,type = 'l',col=rainbow(n),ylab='')
-   legend('topleft', inset=c(0,0),c(colnames(A)),lty=1,col=c(rainbow(n)))
+   legend(location, inset=c(0,0),c(colnames(A)),lty=1,col=c(rainbow(n)))
 
   matplot(A_Normalized,type = 'l',col=rainbow(n),ylab='')
-  legend('topleft',c(paste0(colnames(A)," Normalized")),lty=1,col=c(rainbow(n)))
+  legend(location,c(paste0(colnames(A)," Normalized")),lty=1,col=c(rainbow(n)))
   }}
 
   par(mfrow=c(1,1))
