@@ -19,7 +19,7 @@
 #' @export
 
 LPM<- function(degree,target,variable)
- {sum((target - (variable[variable < target]))^degree)/length(variable)}
+ {sum((target - (variable[variable <= target]))^degree)/length(variable)}
 
 
 
@@ -104,7 +104,7 @@ Co.LPM<- function(degree,target1,target2,variable1,variable2){
   output <- vector("numeric", length(variable1))
   for (i in 1:length(variable1))
   {
-    if (variable1[i]<target1 & variable2[i]<target2)
+    if (variable1[i]<=target1 & variable2[i]<=target2)
 
     output[i]<- (((target1-variable1[i])^degree)*((target2-variable2[i])^degree))
   }
