@@ -52,7 +52,7 @@ FSD <- function(x,y){
   }
 }
 
-#' SSD
+#' VN.SSD.uni
 #'
 #' Uni-directional test of second degree stochastic dominance using lower partial moments used in SD Efficient Set routine.
 #' @param x variable
@@ -61,11 +61,11 @@ FSD <- function(x,y){
 #' @examples
 #' set.seed(123)
 #' x<-rnorm(100); y<-rnorm(100)
-#' \dontrun{SSD(x,y)}
+#' \dontrun{VN.SSD.uni(x,y)}
 #' @export
 
 
-SSD <- function(x,y){
+VN.SSD.uni <- function(x,y){
 
   x_sort <- sort(x, decreasing=FALSE)
   y_sort <- sort(y, decreasing=FALSE)
